"""Document analytics subsystem."""

from altscribe.analytics.base import (
    Analyzer,
    AnalyzerResult,
    BaseAnalyzer,
    Metric,
    MetricCategory,
)

__all__ = [
    "Analyzer",
    "AnalyzerResult",
    "BaseAnalyzer",
    "Metric",
    "MetricCategory",
]
